==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkObjectFactory.java <==
// java wrapper for vtkObjectFactory object
//

package vtk;
import vtk.*;

public class vtkObjectFactory extends vtkObject
{

  private native long CreateInstance_0(String id0,boolean id1);
  public vtkObject CreateInstance(String id0,boolean id1) {
    long temp = CreateInstance_0(id0,id1);

    if (temp == 0) return null;
    return (vtkObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void ConstructInstance_1(String id0);
  public void ConstructInstance(String id0)
    { ConstructInstance_1(id0); }

  private native void CreateAllInstance_2(String id0,vtkCollection id1);
  public void CreateAllInstance(String id0,vtkCollection id1)
    { CreateAllInstance_2(id0,id1); }

  private native void ReHash_3();
  public void ReHash()
    { ReHash_3(); }

  private native void RegisterFactory_4(vtkObjectFactory id0);
  public void RegisterFactory(vtkObjectFactory id0)
    { RegisterFactory_4(id0); }

  private native void UnRegisterFactory_5(vtkObjectFactory id0);
  public void UnRegisterFactory(vtkObjectFactory id0)
    { UnRegisterFactory_5(id0); }

  private native void UnRegisterAllFactories_6();
  public void UnRegisterAllFactories()
    { UnRegisterAllFactories_6(); }

  private native long GetRegisteredFactories_7();
  public vtkObjectFactoryCollection GetRegisteredFactories() {
    long temp = GetRegisteredFactories_7();

    if (temp == 0) return null;
    return (vtkObjectFactoryCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int HasOverrideAny_8(String id0);
  public int HasOverrideAny(String id0)
    { return HasOverrideAny_8(id0); }

  private native void GetOverrideInformation_9(String id0,vtkOverrideInformationCollection id1);
  public void GetOverrideInformation(String id0,vtkOverrideInformationCollection id1)
    { GetOverrideInformation_9(id0,id1); }

  private native void SetAllEnableFlags_10(int id0,String id1);
  public void SetAllEnableFlags(int id0,String id1)
    { SetAllEnableFlags_10(id0,id1); }

  private native void SetAllEnableFlags_11(int id0,String id1,String id2);
  public void SetAllEnableFlags(int id0,String id1,String id2)
    { SetAllEnableFlags_11(id0,id1,id2); }

  private native String GetClassName_12();
  public String GetClassName()
    { return GetClassName_12(); }

  private native int IsA_13(String id0);
  public int IsA(String id0)
    { return IsA_13(id0); }

  private native String GetVTKSourceVersion_14();
  public String GetVTKSourceVersion()
    { return GetVTKSourceVersion_14(); }

  private native String GetDescription_15();
  public String GetDescription()
    { return GetDescription_15(); }

  private native int GetNumberOfOverrides_16();
  public int GetNumberOfOverrides()
    { return GetNumberOfOverrides_16(); }

  private native String GetClassOverrideName_17(int id0);
  public String GetClassOverrideName(int id0)
    { return GetClassOverrideName_17(id0); }

  private native String GetClassOverrideWithName_18(int id0);
  public String GetClassOverrideWithName(int id0)
    { return GetClassOverrideWithName_18(id0); }

  private native int GetEnableFlag_19(int id0);
  public int GetEnableFlag(int id0)
    { return GetEnableFlag_19(id0); }

  private native String GetOverrideDescription_20(int id0);
  public String GetOverrideDescription(int id0)
    { return GetOverrideDescription_20(id0); }

  private native void SetEnableFlag_21(int id0,String id1,String id2);
  public void SetEnableFlag(int id0,String id1,String id2)
    { SetEnableFlag_21(id0,id1,id2); }

  private native int GetEnableFlag_22(String id0,String id1);
  public int GetEnableFlag(String id0,String id1)
    { return GetEnableFlag_22(id0,id1); }

  private native int HasOverride_23(String id0);
  public int HasOverride(String id0)
    { return HasOverride_23(id0); }

  private native int HasOverride_24(String id0,String id1);
  public int HasOverride(String id0,String id1)
    { return HasOverride_24(id0,id1); }

  private native void Disable_25(String id0);
  public void Disable(String id0)
    { Disable_25(id0); }

  private native String GetLibraryPath_26();
  public String GetLibraryPath()
    { return GetLibraryPath_26(); }

  public vtkObjectFactory() { super(); }

  public vtkObjectFactory(long id) { super(id); }

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkObjectFactory.java <==
// java wrapper for vtkObjectFactory object
//

package vtk;
import vtk.*;

public class vtkObjectFactory extends vtkObject
{

  private native long CreateInstance_0(String id0,boolean id1);
  public vtkObject CreateInstance(String id0,boolean id1) {
    long temp = CreateInstance_0(id0,id1);

    if (temp == 0) return null;
    return (vtkObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void ConstructInstance_1(String id0);
  public void ConstructInstance(String id0)
    { ConstructInstance_1(id0); }

  private native void CreateAllInstance_2(String id0,vtkCollection id1);
  public void CreateAllInstance(String id0,vtkCollection id1)
    { CreateAllInstance_2(id0,id1); }

  private native void ReHash_3();
  public void ReHash()
    { ReHash_3(); }

  private native void RegisterFactory_4(vtkObjectFactory id0);
  public void RegisterFactory(vtkObjectFactory id0)
    { RegisterFactory_4(id0); }

  private native void UnRegisterFactory_5(vtkObjectFactory id0);
  public void UnRegisterFactory(vtkObjectFactory id0)
    { UnRegisterFactory_5(id0); }

  private native void UnRegisterAllFactories_6();
  public void UnRegisterAllFactories()
    { UnRegisterAllFactories_6(); }

  private native long GetRegisteredFactories_7();
  public vtkObjectFactoryCollection GetRegisteredFactories() {
    long temp = GetRegisteredFactories_7();

    if (temp == 0) return null;
    return (vtkObjectFactoryCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int HasOverrideAny_8(String id0);
  public int HasOverrideAny(String id0)
    { return HasOverrideAny_8(id0); }

  private native void GetOverrideInformation_9(String id0,vtkOverrideInformationCollection id1);
  public void GetOverrideInformation(String id0,vtkOverrideInformationCollection id1)
    { GetOverrideInformation_9(id0,id1); }

  private native void SetAllEnableFlags_10(int id0,String id1);
  public void SetAllEnableFlags(int id0,String id1)
    { SetAllEnableFlags_10(id0,id1); }

  private native void SetAllEnableFlags_11(int id0,String id1,String id2);
  public void SetAllEnableFlags(int id0,String id1,String id2)
    { SetAllEnableFlags_11(id0,id1,id2); }

  private native int IsTypeOf_12(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_12(id0); }

  private native int IsA_13(String id0);
  public int IsA(String id0)
    { return IsA_13(id0); }

  private native String GetVTKSourceVersion_14();
  public String GetVTKSourceVersion()
    { return GetVTKSourceVersion_14(); }

  private native String GetDescription_15();
  public String GetDescription()
    { return GetDescription_15(); }

  private native int GetNumberOfOverrides_16();
  public int GetNumberOfOverrides()
    { return GetNumberOfOverrides_16(); }

  private native String GetClassOverrideName_17(int id0);
  public String GetClassOverrideName(int id0)
    { return GetClassOverrideName_17(id0); }

  private native String GetClassOverrideWithName_18(int id0);
  public String GetClassOverrideWithName(int id0)
    { return GetClassOverrideWithName_18(id0); }

  private native int GetEnableFlag_19(int id0);
  public int GetEnableFlag(int id0)
    { return GetEnableFlag_19(id0); }

  private native String GetOverrideDescription_20(int id0);
  public String GetOverrideDescription(int id0)
    { return GetOverrideDescription_20(id0); }

  private native void SetEnableFlag_21(int id0,String id1,String id2);
  public void SetEnableFlag(int id0,String id1,String id2)
    { SetEnableFlag_21(id0,id1,id2); }

  private native int GetEnableFlag_22(String id0,String id1);
  public int GetEnableFlag(String id0,String id1)
    { return GetEnableFlag_22(id0,id1); }

  private native int HasOverride_23(String id0);
  public int HasOverride(String id0)
    { return HasOverride_23(id0); }

  private native int HasOverride_24(String id0,String id1);
  public int HasOverride(String id0,String id1)
    { return HasOverride_24(id0,id1); }

  private native void Disable_25(String id0);
  public void Disable(String id0)
    { Disable_25(id0); }

  private native String GetLibraryPath_26();
  public String GetLibraryPath()
    { return GetLibraryPath_26(); }

  public vtkObjectFactory() { super(); }

  public vtkObjectFactory(long id) { super(id); }

}
